dyn_alignr_128

Function dyn_alignr_128 

unsafe fn dyn_alignr_128(a: __m128i, b: __m128i, shift: usize) -> __m128i
This is a version of the alignr intrinsic that takes a non-const shift argument. The shift is still expected to be constant in practice, so the match statement will be optimized out. This exists because Rust doesn’t currently let you do math on const generics.