dyn_alignr_256

Function dyn_alignr_256 

unsafe fn dyn_alignr_256(a: __m256i, b: __m256i, shift: usize) -> __m256i
This is a version of the alignr intrinsic that takes a non-const shift argument. The shift is still expected to be constant in practice, so the match statement will be optimized out. This exists because Rust doesn’t currently let you do math on const generics.